#!/bin/ksh

#===============================================================================
# project:              ImageMedical
# file:                 cleanup.sh
# author:               Ivan Szkiba <szkiba@hu.bonus.com>
# co-author:            Zoltan Kanizsai <qzoltan@appaloosacorp.hu>
# created:              Apryl, 1999.
# description:          Clear temporary directories. Save core files
#                       Runs periodically from cron.
# component:            generic
# usage:                $0 
# commands:             -
# environment:          HOME var
#                       setenv.sh, func.shi scripts in $HOME/etc
#===============================================================================

. $HOME/etc/setenv.sh
. $HOME/etc/func.shi

LogRotateDays=30
[ -f "$CONF/self.rec" ] && . "$CONF/self.rec"
# in self.rec we can override LogRotateDays


Self=`basename $0`
LoggerTag="$Self[$$]"
export Self LoggerTag

Vars="PRESERVE TMP LOG_FACILITY" #CollectCore_ needs GNU_HOME [from bonus] 
Dirs="$PRESERVE $TMP"

# === FUNC =============================

#
# check_err	check error messages of find command, and log if need
#
#	$1	error file name
#
check_err()
{
   ERR_TMP=${ERR}.tmp
   
   egrep -v 'cannot open.*\.tags' $1 | grep -v "bad status" > $ERR_TMP

   # log errors
   if [ -s $ERR_TMP ] ; then
      cat $ERR_TMP | tee /dev/fd/2 | log error
   fi
   rm -f $ERR_TMP
}

#---------------------------------------
# CleanTmp_()     Clean temporary directory
#   $1 - Directory to clean
#   $HOME
#
CleanTmp_()
{
  Cd2Check_ $1 || Bye_ 1
  User=`basename $HOME`

#--- unmount old disk images (ignore errors)
  find . -type f -atime +2 -user $User -name "*.img" -exec $ASROOT testrepository.asr umount {} \; >/dev/null 2>&1
  
#--- clear files
  find . -type f -atime +2 -user $User -exec rm -f {} \; >/dev/null
  Ret="$?"

#--- clear links
  find . -type l -atime +2 -user $User -exec rm -f {} \; >/dev/null
  [ $? != 0 ] && Ret=1

#--- clear directories
# find removes '.' if not used in the last few days and empty,
# that's why we need clean.$$
  echo $$ > clean.$$
  find . -depth -type d -mtime +2 -user $User -exec rmdir {} \; >/dev/null
  [ $? != 0 ] && Ret=1
  rm clean.$$

  return $Ret

} #CleanTmp_()

#---------------------------------------
# CleanLogsDated_()     Clean LogsDated  directory
#   $1 - Directory to clean
#   $HOME
#
CleanLogsDated_()
{
  Cd2Check_ $1 || Bye_ 1
  User=`basename $HOME`

#--- clear day files
  find ./day/ -type f -mtime +1 -user $User -exec rm -f {} \; >/dev/null
  Ret="$?"

#--- clear week files, IN FACT they are month (30 days) now
  find ./week/ -type f -mtime +$LogRotateDays -user $User -exec rm -f {} \; >/dev/null
  [ $? != 0 ] && Ret=1

  return $Ret

} #CleanLogsDated_()


#---------------------------------------
# Do_Preserve_  clean preserve directory
#   $1 - Directory to clean
#   $HOME
#
CleanPreserve_()
{
  Cd2Check_ $1 || Bye_ 1
  User=`basename $HOME`

#--- clear preserved files
  find . -type f -mtime +7 -user $User -exec rm -f {} \; >/dev/null

  return $?

} #CleanPreserve_()

#---------------------------------------
# CollectCore_()    Collect core files
#   $1 - Directory to collect to
#   $HOME $GNU_HOME
#
CollectCore_()
{
  User=`basename $HOME`
  Ret=0

  find $HOME/ -mount -name core -user $User | while read File ; do
    Name=$1/core.$$.$RANDOM
    mv -f $File $Name
    chmod +r $Name
    if [ $? = 0 ] ; then
      $GNU_HOME/gzip $Name
      Log_ error "$File moved and gzipped as $Name.gz"
      Ret=1
    fi
  done

  return $Ret

} #CollectCore_()

# === MAIN =============================
Log_ info Started                       #Logging start entry
ErrLogger_                              #Start error-logging co-process

EnvCheck_ "$Vars" 2>&p || Bye_ 1        #Check environment variables
DirCheck_ "$Dirs" 2>&p || Bye_ 1        #Check/create dirs

Opwd=$PWD   
CleanTmp_ $TMP 2>&p                     #Clean TMP
  Ret="$?"
CleanLogsDated_ $LOGS_DATED 2>&p       #Clean LOGS_DATED
  Ret="$?"
#CleanPreserve_ $PRESERVE 2>&p           #Clean PRESERVE
#  [ $? != 0 ] && Ret=1
#CollectCore_ $PRESERVE 2>&p             #Collect core files
#  [ $? != 0 ] && Ret=1

cd $Opwd
Bye_ $Ret				#Logging end entry
